﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.IO;
using brBaseDLL;

namespace Configuration_Tool
{
    public partial class Form1 : Form
    {
        //Variables
        TextWriter _writer = null;

        public Form1()
        {
            InitializeComponent();
            //redirect output to textbox
            _writer = new TextBoxStreamWriter(textBox_terminal);
            Console.SetOut(_writer);
            //fill combobo with com ports
            comboBox_com.Items.Clear();
            foreach (string s in System.IO.Ports.SerialPort.GetPortNames()) comboBox_com.Items.Add(s);
            comboBox_com.SelectedIndex = comboBox_com.Items.Count - 1;
        }


        //select filepath for bitfile
        private void button_filepath_Click(object sender, EventArgs e)
        {
            //open FileDialog 
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.CheckFileExists = false;
            System.Windows.Forms.DialogResult dr = ofd.ShowDialog();
            if (dr == DialogResult.OK)
            {
                textBox_filepath.Text = ofd.FileName;
            }
        }


        //hide filepath when select reload option
        private void radioButton_reload_CheckedChanged(object sender, EventArgs e)
        {
            if (radioButton_reload.Checked)
            {
                //hide
                button_filepath.Visible = false;
                textBox_filepath.Visible = false;
            }
            else
            {
                //visible
                button_filepath.Visible = true;
                textBox_filepath.Visible = true;
            }
        }


        //Program
        private void button_go_Click(object sender, EventArgs e)
        {
            //select io interface
            String io_interface;
            if (radioButton_USB.Checked)
                //USB
                io_interface = "usb";
            else if (radioButton_ethernet.Checked)
                //Ethernet
                io_interface = textBox_ip.Text;
            else
                //UART (Virtual COM Port)
                io_interface = comboBox_com.Text;
            //select target
            String fpga;
            if (radioButton_user.Checked)
                fpga = "user";
            else
                fpga = "conn";
            //check filepath
            if (!radioButton_reload.Checked && !File.Exists(textBox_filepath.Text))
            {
                Console.WriteLine("... wrong filepath ...");
                return;
            }
            //select programming options
            if (radioButton_volatile.Checked)
                //load bitfile directly to the fpga
                brBase.ctrl_progBitfile(io_interface, fpga, textBox_filepath.Text, true);
            else if (radioButton_nonvolatile.Checked)
                //store bitfile in flash
                brBase.ctrl_saveBitfile(io_interface, fpga, textBox_filepath.Text, true);
            else
                //reload bitfile from flash
                brBase.ctrl_reloadBitfile(io_interface, fpga, true);
        }


    }
}
